{% extends 'tom_common/index.html' %}
<!-- tom_superevent/superevent_detail.html -->
{% block content %}
<!-- block content -->
<h1>Superevent Detail</h1>
{{ object.id }}
{{ object.superevent_id }}
{{ object.superevent_url }}
{% endblock content %}