{% extends 'tom_common/base.html' %}
<!-- tom_superevents/superevent_detail/gamma_ray_burst.html -->
{% block content %}
<!-- block content -->
<h1>Superevent Detail (Gamma-ray Burst)</h1>
{{ object.id }}
{{ object.superevent_id }}
{{ object.superevent_url }}
{% endblock content %}